pub struct Event {
pub seq: u64,
pub time: Timestamp,
pub level: Level,
pub target: String,
pub message: String,
pub fields: BTreeMap<String, LogValue>,
pub dropped: u32,
pub truncated: u32,
}Expand description
One structured runner log event published out-of-band.
Fields
seq: u64time: Timestamplevel: Leveltarget: Stringmessage: Stringfields: BTreeMap<String, LogValue>dropped: u32Complete records lost before publication because a bounded queue or publish attempt was saturated.
truncated: u32Values or fields truncated inside this published record to keep its wire representation bounded.